Module parse

Module parse 

Parse markdown rule files into YAML frontmatter and body text.

Structs

ParsedRule
Parsed rule file: JSON frontmatter value and markdown body.

Functions

is_empty_frontmatter
Returns true when frontmatter is null or an empty object.
parse_rule
Parse a rule file string into frontmatter and body.