pub fn parse_rule(content: &str) -> Result<ParsedRule, Error>Expand description
Parse a rule file string into frontmatter and body.
Empty or missing frontmatter becomes JSON null.
pub fn parse_rule(content: &str) -> Result<ParsedRule, Error>Parse a rule file string into frontmatter and body.
Empty or missing frontmatter becomes JSON null.