JSON Schema validation of rule frontmatter against the embedded schema.
Functions
- validate_
frontmatter - Validate
frontmatteragainst the embedded agent-rules-spec JSON Schema.
JSON Schema validation of rule frontmatter against the embedded schema.
frontmatter against the embedded agent-rules-spec JSON Schema.