pub struct LintOptions {
pub severity_threshold: Severity,
pub filename_hint: Option<String>,
}Expand description
Options controlling lint_string and lint_directory.
Fields
severity_threshold: SeverityMinimum severity that should fail a lint run (CLI exit code).
filename_hint: Option<String>Filename stem used for semantic checks such as name vs filename.